Learn R Programming

precintcon (version 2.1)

pplot.rai: Plot Rainfall Anomaly Index

Description

Plots the Rainfall Anomaly Index of a precipitation serie.

Usage

pplot.rai(..., granularity = "m", xlab = "Month", ylab = "RAI",
					 ylim = c(-3,3), legend = NULL, fontsize = 10,
                axis.text.color = "black", export = FALSE,
					 export.name = "rai_plot.png", width = 8.6,
					    height = 7.5, units = "cm")

Arguments

granularity
the granularity applied for calculating the rainfall anomaly index, which should be either "a" for annual granularity or "m" for monthly granularity ". (Default value: "m")
xlab
the text for the x axis. (Default value: "Month")
ylab
the text for the y axis. (Default value: "RAI")
ylim
the limits of the y axis. (Default value: c(-3, 3))
legend
the text vector for the legend items. If NULL the legends will be equals to the variable names. (Default value: NULL)
fontsize
the font size value in pt. (Default value: 10)
axis.text.color
the legend colors. (Default value: "black")
export
the logical value for defining whether the graph should be export to a file or not. (Default value: FALSE)
export.name
the text for defining the exported file name. It is only used if export = TRUE. (Default value: "rai_plot.png")
width
the number for defining the exported graph width. It is only used if export = TRUE. (Default value: 8.6)
height
the number for defining the exported graph height. It is only used if export = TRUE. (Default value: 7.5)
units
the text for defining the units of the height and width parameters. It is only used if export = TRUE. (Default value: "cm")
...
a set of daily or monthly precipitation series.

See Also

read.data

Examples

Run this code
##
# Loading the daily precipitation serie.
data(daily)

##
# Performing the a set of statistical analysis
pplot.rai(daily, granularity = "m")

Run the code above in your browser using DataLab